# cPkg

## This is a package that generates packages

>## install
>>```shell
>>pip install cpkg
>>```
>## use
>>```python
>>import cpkg
>>cpkg.create(
>>    path='',
>>    dirName='',
>>    pkgName='',
>>    author='',
>>    author_email='',
>>    description='',
>>    url='',
>>    project_urls={},
>>    classifiers=[],
>>    python_requires=3.6,
>>    install_requires=[]
>>)
>>```
## updata
>### 0.0.6 2021 1 19
>>1. Update command:
>>>See details: 
>>>```shell
>>>python3 -m cpkg -h
>>>```
>>
>